@@ -25,9 +25,10 @@ from metpy.units import units
 #######################################
 # **Getting the data**
 #
-# In this example, NARR reanalysis data for 18 UTC 04 April 1987 from the National Centers
-# for Environmental Information (https://www.ncdc.noaa.gov/data-access/model-data)
-# will be used.
+# In this example, [NARR reanalysis data](
+# https://www.ncdc.noaa.gov/data-access/model-data/model-datasets/north-american-regional-reanalysis-narr)
+# for 18 UTC 04 April 1987 from the National Centers for Environmental Information will be
+# used.
 
 data = xr.open_dataset(get_test_data('narr_example.nc', False))
 
@@ -36,22 +37,9 @@ print(list(data.variables))
 
 #############################
 # We will reduce the dimensionality of the data as it is pulled in to remove an empty time
-# dimension.
+# dimension, as well as add longitude and latitude as coordinates (instead of data variables).
 
-# Assign data to variable names
-lat = data['lat']
-lon = data['lon']
-lev = data['isobaric']
-times = data['time']
-
-tmp = data['Temperature'][0]
-uwnd = data['u_wind'][0]
-vwnd = data['v_wind'][0]
-spech = data['Specific_humidity'][0]
-
-# pint doesn't understand gpm
-data['Geopotential_height'].attrs['units'] = 'meter'
-hgt = data['Geopotential_height'][0]
+data = data.squeeze().set_coords(['lon', 'lat'])
 
 #############################
 # To properly interpolate to isentropic coordinates, the function must know the desired output
@@ -64,37 +52,31 @@ isentlevs = [296.] * units.kelvin
 #
 # Once three dimensional data in isobaric coordinates has been pulled and the desired
 # isentropic levels created, the conversion to isentropic coordinates can begin. Data will be
-# passed to the function as below. The function requires that isentropic levels, isobaric
-# levels, and temperature be input. Any additional inputs (in this case relative humidity, u,
-# and v wind components) will be linearly interpolated to isentropic space.
+# passed to the function as below. The function requires that isentropic levels, as well as a
+# DataArray of temperature on isobaric coordinates be input. Any additional inputs (in this
+# case specific humidity, geopotential height, and u and v wind components) will be
+# logarithmicaly interpolated to isentropic space.
 
-isent_anal = mpcalc.isentropic_interpolation(isentlevs,
-                                             lev,
-                                             tmp,
-                                             spech,
-                                             uwnd,
-                                             vwnd,
-                                             hgt,
-                                             tmpk_out=True)
+isent_data = mpcalc.isentropic_interpolation_as_dataset(
+    isentlevs,
+    data['Temperature'],
+    data['u_wind'],
+    data['v_wind'],
+    data['Specific_humidity'],
+    data['Geopotential_height']
+)
 
 #####################################
-# The output is a list, so now we will separate the variables to different names before
-# plotting.
+# The output is an xarray Dataset:
 
-isentprs, isenttmp, isentspech, isentu, isentv, isenthgt = isent_anal
-isentu.ito('kt')
-isentv.ito('kt')
+isent_data
 
 ########################################
-# A quick look at the shape of these variables will show that the data is now in isentropic
-# coordinates, with the number of vertical levels as specified above.
+# Note that the units on our wind variables are not ideal for plotting. Instead, let us
+# convert them to more appropriate values.
 
-print(isentprs.shape)
-print(isentspech.shape)
-print(isentu.shape)
-print(isentv.shape)
-print(isenttmp.shape)
-print(isenthgt.shape)
+isent_data['u_wind'] = isent_data['u_wind'].metpy.convert_units('kt')
+isent_data['v_wind'] = isent_data['v_wind'].metpy.convert_units('kt')
 
 #################################
 # **Converting to Relative Humidity**
@@ -102,17 +84,23 @@ print(isenthgt.shape)
 # The NARR only gives specific humidity on isobaric vertical levels, so relative humidity will
 # have to be calculated after the interpolation to isentropic space.
 
-isentrh = 100 * mpcalc.relative_humidity_from_specific_humidity(isentspech, isenttmp, isentprs)
+isent_data['Relative_humidity'] = mpcalc.relative_humidity_from_specific_humidity(
+    isent_data['pressure'],
+    isent_data['temperature'],
+    isent_data['Specific_humidity']
+).metpy.convert_units('percent')
 
 #######################################
 # **Plotting the Isentropic Analysis**
 
-# Set up our projection
+# Set up our projection and coordinates
 crs = ccrs.LambertConformal(central_longitude=-100.0, central_latitude=45.0)
+lon = isent_data['pressure'].metpy.longitude
+lat = isent_data['pressure'].metpy.latitude
 
 # Coordinates to limit map area
 bounds = [(-122., -75., 25., 50.)]
-# Choose a level to plot, in this case 296 K
+# Choose a level to plot, in this case 296 K (our sole level in this example)
 level = 0
 
 fig = plt.figure(figsize=(17., 12.))
@@ -124,26 +112,28 @@ ax.add_feature(cfeature.STATES, linewidth=0.5)
 
 # Plot the surface
 clevisent = np.arange(0, 1000, 25)
-cs = ax.contour(lon, lat, isentprs[level, :, :], clevisent,
-                colors='k', linewidths=1.0, linestyles='solid', transform=ccrs.PlateCarree())
-ax.clabel(cs, fontsize=10, inline=1, inline_spacing=7,
-          fmt='%i', rightside_up=True, use_clabeltext=True)
+cs = ax.contour(lon, lat, isent_data['pressure'].isel(isentropic_level=level),
+                clevisent, colors='k', linewidths=1.0, linestyles='solid',
+                transform=ccrs.PlateCarree())
+cs.clabel(fontsize=10, inline=1, inline_spacing=7, fmt='%i', rightside_up=True,
+          use_clabeltext=True)
 
 # Plot RH
-cf = ax.contourf(lon, lat, isentrh[level, :, :], range(10, 106, 5),
-                 cmap=plt.cm.gist_earth_r, transform=ccrs.PlateCarree())
-cb = fig.colorbar(cf, orientation='horizontal', extend='max', aspect=65, shrink=0.5, pad=0.05,
+cf = ax.contourf(lon, lat, isent_data['Relative_humidity'].isel(isentropic_level=level),
+                 range(10, 106, 5), cmap=plt.cm.gist_earth_r, transform=ccrs.PlateCarree())
+cb = fig.colorbar(cf, orientation='horizontal', aspect=65, shrink=0.5, pad=0.05,
                   extendrect='True')
 cb.set_label('Relative Humidity', size='x-large')
 
 # Plot wind barbs
-ax.barbs(lon.values, lat.values, isentu[level, :, :].m, isentv[level, :, :].m, length=6,
+ax.barbs(lon.values, lat.values, isent_data['u_wind'].isel(isentropic_level=level).values,
+         isent_data['v_wind'].isel(isentropic_level=level).values, length=6,
          regrid_shape=20, transform=ccrs.PlateCarree())
 
 # Make some titles
-ax.set_title('{:.0f} K Isentropic Pressure (hPa), Wind (kt), Relative Humidity (percent)'
-             .format(isentlevs[level].m), loc='left')
-add_timestamp(ax, times[0].values.astype('datetime64[ms]').astype('O'),
+ax.set_title(f'{isentlevs[level]:~.0f} Isentropic Pressure (hPa), Wind (kt), '
+             'Relative Humidity (percent)', loc='left')
+add_timestamp(ax, isent_data['time'].values.astype('datetime64[ms]').astype('O'),
               y=0.02, high_contrast=True)
 fig.tight_layout()
 
@@ -156,7 +146,10 @@ fig.tight_layout()
 
 
 # Calculate Montgomery Streamfunction and scale by 10^-2 for plotting
-msf = mpcalc.montgomery_streamfunction(isenthgt, isenttmp) / 100.
+msf = mpcalc.montgomery_streamfunction(
+    isent_data['Geopotential_height'],
+    isent_data['temperature']
+).values / 100.
 
 # Choose a level to plot, in this case 296 K
 level = 0
@@ -172,24 +165,25 @@ ax.add_feature(cfeature.STATES.with_scale('50m'), linewidth=0.5)
 clevmsf = np.arange(0, 4000, 5)
 cs = ax.contour(lon, lat, msf[level, :, :], clevmsf,
                 colors='k', linewidths=1.0, linestyles='solid', transform=ccrs.PlateCarree())
-ax.clabel(cs, fontsize=10, inline=1, inline_spacing=7,
-          fmt='%i', rightside_up=True, use_clabeltext=True)
+cs.clabel(fontsize=10, inline=1, inline_spacing=7, fmt='%i', rightside_up=True,
+          use_clabeltext=True)
 
 # Plot RH
-cf = ax.contourf(lon, lat, isentrh[level, :, :], range(10, 106, 5),
-                 cmap=plt.cm.gist_earth_r, transform=ccrs.PlateCarree())
-cb = fig.colorbar(cf, orientation='horizontal', extend='max', aspect=65, shrink=0.5, pad=0.05,
+cf = ax.contourf(lon, lat, isent_data['Relative_humidity'].isel(isentropic_level=level),
+                 range(10, 106, 5), cmap=plt.cm.gist_earth_r, transform=ccrs.PlateCarree())
+cb = fig.colorbar(cf, orientation='horizontal', aspect=65, shrink=0.5, pad=0.05,
                   extendrect='True')
 cb.set_label('Relative Humidity', size='x-large')
 
-# Plot wind barbs.
-ax.barbs(lon.values, lat.values, isentu[level, :, :].m, isentv[level, :, :].m, length=6,
+# Plot wind barbs
+ax.barbs(lon.values, lat.values, isent_data['u_wind'].isel(isentropic_level=level).values,
+         isent_data['v_wind'].isel(isentropic_level=level).values, length=6,
          regrid_shape=20, transform=ccrs.PlateCarree())
 
 # Make some titles
-ax.set_title('{:.0f} K Montgomery Streamfunction '.format(isentlevs[level].m)
-             + r'($10^{-2} m^2 s^{-2}$), Wind (kt), Relative Humidity (percent)', loc='left')
-add_timestamp(ax, times[0].values.astype('datetime64[ms]').astype('O'),
+ax.set_title(f'{isentlevs[level]:~.0f} Montgomery Streamfunction '
+             r'($10^{-2} m^2 s^{-2}$), Wind (kt), Relative Humidity (percent)', loc='left')
+add_timestamp(ax, isent_data['time'].values.astype('datetime64[ms]').astype('O'),
               y=0.02, pretext='Valid: ', high_contrast=True)
 
 fig.tight_layout()
