@@ -306,8 +306,8 @@ def heat_index(temperature, relative_humidity, mask_undefined=True):
         rh15adj = ((13. - relative_humidity[sel] * 100.) / 4.
                    * np.sqrt((units.Quantity(17., 'delta_degF')
                               - np.abs(delta[sel] - units.Quantity(95., 'delta_degF')))
-                             / units.Quantity(17., 'delta_degF')))
-        hi[sel] = hi[sel] - units.Quantity(rh15adj, 'delta_degF')
+                             / units.Quantity(17., '1/delta_degF')))
+        hi[sel] = hi[sel] - rh15adj
 
     # Adjustment for RH > 85% and 80F <= T <= 87F
     sel = ((relative_humidity > units.Quantity(85., 'percent'))
@@ -496,6 +496,7 @@ def height_to_geopotential(height):
 
 @exporter.export
 @preprocess_and_wrap(wrap_like='geopotential')
+@check_units('[length] ** 2 / [time] ** 2')
 def geopotential_to_height(geopotential):
     r"""Compute height above sea level from a given geopotential.
 
@@ -794,9 +795,9 @@ def smooth_gaussian(scalar_grid, n):
     sgma = n / (2 * np.pi)
 
     # Construct sigma sequence so smoothing occurs only in horizontal direction
-    nax = len(scalar_grid.shape)
+    num_ax = len(scalar_grid.shape)
     # Assume the last two axes represent the horizontal directions
-    sgma_seq = [sgma if i > nax - 3 else 0 for i in range(nax)]
+    sgma_seq = [sgma if i > num_ax - 3 else 0 for i in range(num_ax)]
 
     # Compute smoothed field
     return gaussian_filter(scalar_grid, sgma_seq, truncate=2 * np.sqrt(2))
@@ -837,7 +838,7 @@ def smooth_window(scalar_grid, window, passes=1, normalize_weights=True):
     function will leave an unsmoothed edge of size `(n - 1) / 2` for each `n` in the shape of
     `window` around the data). If a masked value or NaN values exists in the array, it will
     propagate to any point that uses that particular grid point in the smoothing calculation.
-    Applying the smoothing function multiple times will propogate NaNs further throughout the
+    Applying the smoothing function multiple times will propagate NaNs further throughout the
     domain.
 
     See Also
@@ -861,7 +862,7 @@ def smooth_window(scalar_grid, window, passes=1, normalize_weights=True):
         # Add ... to the front of an indexer, since we are working with trailing dimensions.
         return (Ellipsis,) + tuple(indexer)
 
-    # Verify that shape in all dimensions is odd (need to have a neighboorhood around a
+    # Verify that shape in all dimensions is odd (need to have a neighborhood around a
     # central point)
     if any((size % 2 == 0) for size in window.shape):
         raise ValueError('The shape of the smoothing window must be odd in all dimensions.')
@@ -921,7 +922,7 @@ def smooth_rectangular(scalar_grid, size, passes=1):
     function will leave an unsmoothed edge of size `(n - 1) / 2` for each `n` in `size` around
     the data). If a masked value or NaN values exists in the array, it will propagate to any
     point that uses that particular grid point in the smoothing calculation. Applying the
-    smoothing function multiple times will propogate NaNs further throughout the domain.
+    smoothing function multiple times will propagate NaNs further throughout the domain.
 
     See Also
     --------
@@ -960,7 +961,7 @@ def smooth_circular(scalar_grid, radius, passes=1):
     function will leave an unsmoothed edge of size `radius` around the data). If a masked
     value or NaN values exists in the array, it will propagate to any point that uses that
     particular grid point in the smoothing calculation. Applying the smoothing function
-    multiple times will propogate NaNs further throughout the domain.
+    multiple times will propagate NaNs further throughout the domain.
 
     See Also
     --------
@@ -1007,7 +1008,7 @@ def smooth_n_point(scalar_grid, n=5, passes=1):
     the end points with their original values (this function will leave an unsmoothed edge of
     size 1 around the data). If a masked value or NaN values exists in the array, it will
     propagate to any point that uses that particular grid point in the smoothing calculation.
-    Applying the smoothing function multiple times will propogate NaNs further throughout the
+    Applying the smoothing function multiple times will propagate NaNs further throughout the
     domain.
 
     See Also
@@ -1164,13 +1165,13 @@ def altimeter_to_sea_level_pressure(altimeter_value, height, temperature):
 
     Equation 2.31:
      .. math::
-       p_{0} = p_{g}exp \left(\frac{Z_{g}}{\bar H} \right) \\
+       p_{0} = p_{g}exp \left(\frac{Z_{g}}{\bar H} \right)
        = p_{g}exp \left(\frac{g_{0}Z_{g}}{R_{d}\bar T_{v}} \right)
 
-    Then by substituting :math:`Delta_{Z}` for :math:`Z_{g}` in Equation 2.31:
-     .. math:: p_{sea_level} = p_{station} exp\left(\frac{\Delta z}{H}\right)
+    Then by substituting :math:`\Delta_{Z}` for :math:`Z_{g}` in Equation 2.31:
+     .. math:: p_{sealevel} = p_{station} exp\left(\frac{\Delta z}{H}\right)
 
-    where :math:`Delta_{Z}` is the elevation in meters and :math:`H = \frac{R_{d}T}{g}`
+    where :math:`\Delta_{Z}` is the elevation in meters and :math:`H = \frac{R_{d}T}{g}`
 
     """
     # Calculate the station pressure using function altimeter_to_station_pressure()
