@@ -4,6 +4,7 @@
 """Contains a collection of generally useful calculation tools."""
 import functools
 from operator import itemgetter
+import warnings
 
 import numpy as np
 from numpy.core.numeric import normalize_axis_index
@@ -121,7 +122,7 @@ def find_intersections(x, a, b, direction='all', log_x=False):
 
     Notes
     -----
-    This function implicity converts `xarray.DataArray` to `pint.Quantity`, with the results
+    This function implicitly converts `xarray.DataArray` to `pint.Quantity`, with the results
     given as `pint.Quantity`.
 
     """
@@ -230,7 +231,7 @@ def _delete_masked_points(*arrs):
     """
     if any(hasattr(a, 'mask') for a in arrs):
         keep = ~functools.reduce(np.logical_or, (np.ma.getmaskarray(a) for a in arrs))
-        return tuple(ma.asarray(a[keep]) for a in arrs)
+        return tuple(a[keep] for a in arrs)
     else:
         return arrs
 
@@ -247,6 +248,9 @@ def reduce_point_density(points, radius, priority=None):
     stations with higher precipitation remain in the mask). The points and radius can be
     specified with units. If none are provided, meters are assumed.
 
+    Points with at least one non-finite (i.e. NaN or Inf) value are ignored and returned with
+    a value of ``False`` (meaning don't keep).
+
     Parameters
     ----------
     points : (N, K) array-like
@@ -282,6 +286,11 @@ def reduce_point_density(points, radius, priority=None):
     if points.ndim < 2:
         points = points.reshape(-1, 1)
 
+    # Identify good points--finite values (e.g. not NaN or inf). Set bad 0, but we're going to
+    # ignore anyway. It's easier for managing indices to keep the original points in the group.
+    good_vals = np.isfinite(points)
+    points = np.where(good_vals, points, 0)
+
     # Make a kd-tree to speed searching of data.
     tree = cKDTree(points)
 
@@ -294,8 +303,8 @@ def reduce_point_density(points, radius, priority=None):
         # Take advantage of iterator nature of range here to avoid making big lists
         sorted_indices = range(len(points))
 
-    # Keep all points initially
-    keep = np.ones(len(points), dtype=bool)
+    # Keep all good points initially
+    keep = np.logical_and.reduce(good_vals, axis=-1)
 
     # Loop over all the potential points
     for ind in sorted_indices:
@@ -338,6 +347,7 @@ def _get_bound_pressure_height(pressure, bound, height=None, interpolate=True):
     """
     # avoid circular import if basic.py ever imports something from tools.py
     from .basic import height_to_pressure_std, pressure_to_height_std
+
     # Make sure pressure is monotonically decreasing
     sort_inds = np.argsort(pressure)[::-1]
     pressure = pressure[sort_inds]
@@ -345,7 +355,7 @@ def _get_bound_pressure_height(pressure, bound, height=None, interpolate=True):
         height = height[sort_inds]
 
     # Bound is given in pressure
-    if bound.dimensionality == {'[length]': -1.0, '[mass]': 1.0, '[time]': -2.0}:
+    if bound.check('[length]**-1 * [mass] * [time]**-2'):
         # If the bound is in the pressure data, we know the pressure bound exactly
         if bound in pressure:
             # By making sure this is at least a 1D array we avoid the behavior in numpy
@@ -375,7 +385,7 @@ def _get_bound_pressure_height(pressure, bound, height=None, interpolate=True):
                     bound_height = pressure_to_height_std(bound_pressure)
 
     # Bound is given in height
-    elif bound.dimensionality == {'[length]': 1.0}:
+    elif bound.check('[length]'):
         # If there is height data, see if we have the bound or need to interpolate/find nearest
         if height is not None:
             if bound in height:  # Bound is in the height data
@@ -388,9 +398,8 @@ def _get_bound_pressure_height(pressure, bound, height=None, interpolate=True):
                     # Need to cast back to the input type since interp (up to at least numpy
                     # 1.13 always returns float64. This can cause upstream users problems,
                     # resulting in something like np.append() to upcast.
-                    bound_pressure = units.Quantity(np.interp(np.atleast_1d(bound.m), height.m,
-                                                    pressure.m).astype(np.result_type(bound)),
-                                                    pressure.units)
+                    bound_pressure = np.interp(np.atleast_1d(bound),
+                                               height, pressure).astype(np.result_type(bound))
                 else:
                     idx = (np.abs(height - bound)).argmin()
                     bound_pressure = pressure[idx]
@@ -581,9 +590,9 @@ def get_layer(pressure, *args, height=None, bottom=None, depth=None, interpolate
                                                                 interpolate=interpolate)
 
     # Calculate the top in whatever units depth is in
-    if depth.dimensionality == {'[length]': -1.0, '[mass]': 1.0, '[time]': -2.0}:
+    if depth.check('[length]**-1 * [mass] * [time]**-2'):
         top = bottom_pressure - depth
-    elif depth.dimensionality == {'[length]': 1}:
+    elif depth.check('[length]'):
         top = bottom_height + depth
     else:
         raise ValueError('Depth must be specified in units of length or pressure')
@@ -887,6 +896,16 @@ def azimuth_range_to_lat_lon(azimuths, ranges, center_lon, center_lat, geod=None
     else:
         g = geod
 
+    try:  # convert range units to meters
+        ranges = ranges.m_as('meters')
+    except AttributeError:  # no units associated
+        warnings.warn('Range values are not a Pint-Quantity, assuming values are in meters.')
+    try:  # convert azimuth units to degrees
+        azimuths = azimuths.m_as('degrees')
+    except AttributeError:  # no units associated
+        warnings.warn(
+            'Azimuth values are not a Pint-Quantity, assuming values are in degrees.'
+        )
     rng2d, az2d = np.meshgrid(ranges, azimuths)
     lats = np.full(az2d.shape, center_lat)
     lons = np.full(az2d.shape, center_lon)
@@ -1309,7 +1328,7 @@ def parse_angle(input_dir):
     """Calculate the meteorological angle from directional text.
 
     Works for abbrieviations or whole words (E -> 90 | South -> 180)
-    and also is able to parse 22.5 degreee angles such as ESE/East South East.
+    and also is able to parse 22.5 degree angles such as ESE/East South East.
 
     Parameters
     ----------
