@@ -321,7 +321,7 @@ def interpolate_to_points(points, values, xi, interp_type='linear', minimum_neig
     rbf_func: str
         Specifies which function to use for Rbf interpolation.
         Options include: 'multiquadric', 'inverse', 'gaussian', 'linear', 'cubic',
-        'quintic', and 'thin_plate'. Defualt 'linear'. See `scipy.interpolate.Rbf` for more
+        'quintic', and 'thin_plate'. Default 'linear'. See `scipy.interpolate.Rbf` for more
         information.
     rbf_smooth: float
         Smoothing value applied to rbf interpolation.  Higher values result in more smoothing.
