@@ -13,19 +13,18 @@ import pytest
 import xarray as xr
 
 from metpy.calc import (angle_to_direction, find_bounding_indices, find_intersections,
-                        first_derivative, get_layer, get_layer_heights, gradient,
-                        laplacian, lat_lon_grid_deltas, nearest_intersection_idx, parse_angle,
+                        first_derivative, get_layer, get_layer_heights, gradient, laplacian,
+                        lat_lon_grid_deltas, nearest_intersection_idx, parse_angle,
                         pressure_to_height_std, reduce_point_density, resample_nn_1d,
                         second_derivative)
 from metpy.calc.tools import (_delete_masked_points, _get_bound_pressure_height,
                               _greater_or_close, _less_or_close, _next_non_masked_element,
                               _remove_nans, azimuth_range_to_lat_lon, BASE_DEGREE_MULTIPLIER,
                               DIR_STRS, UND)
-from metpy.testing import (assert_almost_equal, assert_array_almost_equal, assert_array_equal)
+from metpy.testing import assert_almost_equal, assert_array_almost_equal, assert_array_equal
 from metpy.units import units
 from metpy.xarray import grid_deltas_from_dataarray
 
-
 FULL_CIRCLE_DEGREES = np.arange(0, 360, BASE_DEGREE_MULTIPLIER.m) * units.degree
 
 
@@ -151,6 +150,15 @@ def test_reduce_point_density(thin_point_data, radius, truth):
     assert_array_equal(reduce_point_density(thin_point_data, radius=radius), truth)
 
 
+def test_reduce_point_density_nonfinite():
+    """Test that non-finite point values are properly marked not to keep."""
+    points = np.array(
+        [(np.nan, np.nan), (np.nan, 5), (5, 5), (5, np.nan),
+         (10, 10), (np.inf, 10), (10, np.inf), (np.inf, np.inf)])
+    mask = reduce_point_density(points, 1)
+    assert_array_equal(mask, [False, False, True, False, True, False, False, False])
+
+
 @pytest.mark.parametrize('radius, truth',
                          [(2.0, np.array([1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                                           0, 0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=bool)),
@@ -358,6 +366,20 @@ def test_get_layer(pressure, variable, heights, bottom, depth, interp, expected)
     assert_array_almost_equal(y_layer, expected[1], 3)
 
 
+def test_get_layer_units():
+    """Test get_layer when height profile has different units from bottom and depth."""
+    pressure, temperature = layer_test_data()
+    height = units.Quantity(np.linspace(100, 50000, len(pressure)), 'm')
+    pres_subset, temp_subset = get_layer(pressure, temperature,
+                                         bottom=units.Quantity(1, 'km'),
+                                         depth=units.Quantity(5, 'km'),
+                                         height=height)
+    pres_expected = units.Quantity([983, 900, 893], 'hPa')
+    temp_expected = units.Quantity([23.64385006, 16.66666667, 16.11422559], 'degC')
+    assert_array_almost_equal(pres_subset, pres_expected, 2)
+    assert_array_almost_equal(temp_subset, temp_expected, 3)
+
+
 def test_get_layer_masked():
     """Test get_layer with masked arrays as input."""
     p = units.Quantity(np.ma.array([1000, 500, 400]), 'hPa')
@@ -907,7 +929,8 @@ def test_azimuth_range_to_lat_lon():
     rng = [2125., 64625., 127125., 189625., 252125., 314625.]
     clon = -89.98416666666667
     clat = 32.27972222222222
-    output_lon, output_lat = azimuth_range_to_lat_lon(az, rng, clon, clat)
+    with pytest.warns(UserWarning, match='not a Pint-Quantity'):
+        output_lon, output_lat = azimuth_range_to_lat_lon(az, rng, clon, clat)
     true_lon = [[-89.9946968, -90.3061798, -90.6211612, -90.9397425, -91.2620282,
                 -91.5881257],
                 [-89.9938369, -90.2799198, -90.5692874, -90.8620385, -91.1582743,
@@ -934,8 +957,8 @@ def test_azimuth_range_to_lat_lon():
 
 def test_azimuth_range_to_lat_lon_diff_ellps():
     """Test conversion of azimuth and range to lat/lon grid."""
-    az = [332.2403, 334.6765, 337.2528, 339.73846, 342.26257]
-    rng = [2125., 64625., 127125., 189625., 252125., 314625.]
+    az = [332.2403, 334.6765, 337.2528, 339.73846, 342.26257] * units.degrees
+    rng = [2125., 64625., 127125., 189625., 252125., 314625.] * units.meters
     clon = -89.98416666666667
     clat = 32.27972222222222
     output_lon, output_lat = azimuth_range_to_lat_lon(az, rng, clon, clat, Geod(ellps='WGS84'))
@@ -1017,7 +1040,8 @@ def test_first_derivative_xarray_lonlat(test_da_lonlat):
     # Build the xarray of the desired values
     partial = xr.DataArray(
         np.array([-3.30782978e-06, -3.42816074e-06, -3.57012948e-06, -3.73759364e-06]),
-        coords=(('lat', test_da_lonlat['lat']),)
+        coords={'lat': test_da_lonlat['lat']},
+        dims=('lat',)
     )
     _, truth = xr.broadcast(test_da_lonlat, partial)
     truth.coords['metpy_crs'] = test_da_lonlat['metpy_crs']
@@ -1071,7 +1095,8 @@ def test_second_derivative_xarray_lonlat(test_da_lonlat):
     # Build the xarray of the desired values
     partial = xr.DataArray(
         np.array([1.67155420e-14, 1.67155420e-14, 1.74268211e-14, 1.74268211e-14]),
-        coords=(('lat', test_da_lonlat['lat']),)
+        coords={'lat': test_da_lonlat['lat']},
+        dims=('lat',)
     )
     _, truth = xr.broadcast(test_da_lonlat, partial)
     truth.coords['metpy_crs'] = test_da_lonlat['metpy_crs']
@@ -1099,7 +1124,8 @@ def test_gradient_xarray(test_da_xy):
 
     partial = xr.DataArray(
         np.array([0.04129204, 0.03330003, 0.02264402]),
-        coords=(('isobaric', test_da_xy['isobaric']),)
+        coords={'isobaric': test_da_xy['isobaric']},
+        dims=('isobaric',)
     )
     _, truth_p = xr.broadcast(test_da_xy, partial)
     truth_p.coords['metpy_crs'] = test_da_xy['metpy_crs']
@@ -1183,7 +1209,8 @@ def test_laplacian_xarray_lonlat(test_da_lonlat):
     # Build the xarray of the desired values
     partial = xr.DataArray(
         np.array([1.67155420e-14, 1.67155420e-14, 1.74268211e-14, 1.74268211e-14]),
-        coords=(('lat', test_da_lonlat['lat']),)
+        coords={'lat': test_da_lonlat['lat']},
+        dims=('lat',)
     )
     _, truth = xr.broadcast(test_da_lonlat, partial)
     truth.coords['metpy_crs'] = test_da_lonlat['metpy_crs']
