@@ -11,26 +11,22 @@ from metpy.calc import (brunt_vaisala_frequency, brunt_vaisala_frequency_squared
                         brunt_vaisala_period, cape_cin, density, dewpoint,
                         dewpoint_from_relative_humidity, dewpoint_from_specific_humidity,
                         dry_lapse, dry_static_energy, el, equivalent_potential_temperature,
-                        exner_function, gradient_richardson_number, isentropic_interpolation,
-                        isentropic_interpolation_as_dataset, lcl, lfc, lifted_index,
-                        mixed_layer, mixed_layer_cape_cin, mixed_parcel, mixing_ratio,
-                        mixing_ratio_from_relative_humidity,
-                        mixing_ratio_from_specific_humidity, moist_lapse,
-                        moist_static_energy, most_unstable_cape_cin, most_unstable_parcel,
-                        parcel_profile, parcel_profile_with_lcl,
-                        parcel_profile_with_lcl_as_dataset, potential_temperature,
-                        psychrometric_vapor_pressure_wet,
-                        relative_humidity_from_dewpoint,
-                        relative_humidity_from_mixing_ratio,
+                        exner_function, gradient_richardson_number, InvalidSoundingError,
+                        isentropic_interpolation, isentropic_interpolation_as_dataset, lcl,
+                        lfc, lifted_index, mixed_layer, mixed_layer_cape_cin, mixed_parcel,
+                        mixing_ratio, mixing_ratio_from_relative_humidity,
+                        mixing_ratio_from_specific_humidity, moist_lapse, moist_static_energy,
+                        most_unstable_cape_cin, most_unstable_parcel, parcel_profile,
+                        parcel_profile_with_lcl, parcel_profile_with_lcl_as_dataset,
+                        potential_temperature, psychrometric_vapor_pressure_wet,
+                        relative_humidity_from_dewpoint, relative_humidity_from_mixing_ratio,
                         relative_humidity_from_specific_humidity,
                         relative_humidity_wet_psychrometric,
-                        saturation_equivalent_potential_temperature,
-                        saturation_mixing_ratio,
-                        saturation_vapor_pressure,
-                        specific_humidity_from_dewpoint,
-                        specific_humidity_from_mixing_ratio, static_stability,
-                        surface_based_cape_cin, temperature_from_potential_temperature,
-                        thickness_hydrostatic,
+                        saturation_equivalent_potential_temperature, saturation_mixing_ratio,
+                        saturation_vapor_pressure, showalter_index,
+                        specific_humidity_from_dewpoint, specific_humidity_from_mixing_ratio,
+                        static_stability, surface_based_cape_cin,
+                        temperature_from_potential_temperature, thickness_hydrostatic,
                         thickness_hydrostatic_from_relative_humidity, vapor_pressure,
                         vertical_velocity, vertical_velocity_pressure,
                         virtual_potential_temperature, virtual_temperature,
@@ -61,25 +57,25 @@ def test_relative_humidity_from_dewpoint_xarray():
 
 def test_exner_function():
     """Test Exner function calculation."""
-    pres = np.array([900., 500., 300., 100.]) * units.mbar
+    pressure = np.array([900., 500., 300., 100.]) * units.mbar
     truth = np.array([0.97034558, 0.82033536, 0.70893444, 0.51794747]) * units.dimensionless
-    assert_array_almost_equal(exner_function(pres), truth, 5)
+    assert_array_almost_equal(exner_function(pressure), truth, 5)
 
 
 def test_potential_temperature():
     """Test potential_temperature calculation."""
     temp = np.array([278., 283., 291., 298.]) * units.kelvin
-    pres = np.array([900., 500., 300., 100.]) * units.mbar
+    pressure = np.array([900., 500., 300., 100.]) * units.mbar
     real_th = np.array([286.496, 344.981, 410.475, 575.348]) * units.kelvin
-    assert_array_almost_equal(potential_temperature(pres, temp), real_th, 3)
+    assert_array_almost_equal(potential_temperature(pressure, temp), real_th, 3)
 
 
 def test_temperature_from_potential_temperature():
     """Test temperature_from_potential_temperature calculation."""
     theta = np.array([286.12859679, 288.22362587, 290.31865495, 292.41368403]) * units.kelvin
-    pres = np.array([850] * 4) * units.mbar
+    pressure = np.array([850] * 4) * units.mbar
     real_t = np.array([273.15, 275.15, 277.15, 279.15]) * units.kelvin
-    assert_array_almost_equal(temperature_from_potential_temperature(pres, theta),
+    assert_array_almost_equal(temperature_from_potential_temperature(pressure, theta),
                               real_t, 2)
 
 
@@ -117,23 +113,17 @@ def test_dry_lapse_2_levels():
     assert_array_almost_equal(temps, [293., 240.3583] * units.kelvin, 4)
 
 
-def test_moist_lapse():
-    """Test moist_lapse calculation."""
+@pytest.mark.parametrize('temp_units', ['degF', 'degC', 'K'])
+def test_moist_lapse(temp_units):
+    """Test moist_lapse with various temperature units."""
+    starting_temp = 19.85 * units.degC
     temp = moist_lapse(np.array([1000., 800., 600., 500., 400.]) * units.mbar,
-                       293. * units.kelvin)
+                       starting_temp.to(temp_units))
     true_temp = np.array([293, 284.64, 272.81, 264.42, 252.91]) * units.kelvin
     assert_array_almost_equal(temp, true_temp, 2)
 
 
-def test_moist_lapse_degc():
-    """Test moist_lapse with Celsius temperatures."""
-    temp = moist_lapse(np.array([1000., 800., 600., 500., 400.]) * units.mbar,
-                       19.85 * units.degC)
-    true_temp = np.array([293, 284.64, 272.81, 264.42, 252.91]) * units.kelvin
-    assert_array_almost_equal(temp, true_temp, 2)
-
-
-def test_moist_lapse_ref_pres():
+def test_moist_lapse_ref_pressure():
     """Test moist_lapse with a reference pressure."""
     temp = moist_lapse(np.array([1050., 800., 600., 500., 400.]) * units.mbar,
                        19.85 * units.degC, 1000. * units.mbar)
@@ -194,6 +184,16 @@ def test_parcel_profile_lcl():
     assert_array_almost_equal(prof, true_prof, 2)
 
 
+def test_parcel_profile_lcl_not_monotonic():
+    """Test parcel profile with lcl calculation."""
+    with pytest.raises(InvalidSoundingError):
+        p = np.array([1004., 1000., 943., 925., 928., 850., 839., 749., 700.]) * units.hPa
+        t = np.array([24.2, 24., 20.2, 21.6, 21.4, 20.4, 20.2, 14.4, 13.2]) * units.degC
+        td = np.array([21.9, 22.1, 19.2, 20.5, 20.4, 18.4, 17.4, 8.4, -2.8]) * units.degC
+
+        _ = parcel_profile_with_lcl(p, t, td)
+
+
 def test_parcel_profile_with_lcl_as_dataset():
     """Test parcel profile with lcl calculation with xarray."""
     p = np.array([1004., 1000., 943., 928., 925., 850., 839., 749., 700., 699.]) * units.hPa
@@ -1453,9 +1453,12 @@ def test_brunt_vaisala_period(bv_data):
     assert_almost_equal(bv_period, truth, 6)
 
 
-def test_wet_bulb_temperature():
+@pytest.mark.parametrize('temp_units', ['degF', 'degC', 'K'])
+def test_wet_bulb_temperature(temp_units):
     """Test wet bulb calculation with scalars."""
-    val = wet_bulb_temperature(1000 * units.hPa, 25 * units.degC, 15 * units.degC)
+    temp = 25 * units.degC
+    dewp = 15 * units.degC
+    val = wet_bulb_temperature(1000 * units.hPa, temp.to(temp_units), dewp.to(temp_units))
     truth = 18.3432116 * units.degC  # 18.59 from NWS calculator
     assert_almost_equal(val, truth, 5)
 
@@ -1493,7 +1496,8 @@ def test_wet_bulb_temperature_2d():
     assert_array_almost_equal(val, truth, 5)
 
 
-def test_wet_bulb_nan():
+@pytest.mark.parametrize('temp_units', ['degF', 'degC', 'K'])
+def test_wet_bulb_nan(temp_units):
     """Test wet bulb calculation with nans."""
     pressure = [1000.0, 975.0, 950.0, 925.0, 900.0, 850.0, 800.0, 750.0, 700.0, 650.0, 600.0,
                 550.0, 500.0, 450.0, 400.0, 350.0, 300.0, 250.0, 200.0, 150.0, 100.0, 70.0,
@@ -1515,7 +1519,7 @@ def test_wet_bulb_nan():
                    -48.2122467, -39.66942444, -34.30999451, -33.35002747, -23.31001892,
                    -14.55002441, -11.74678955, -25.58999634] * units.degC
 
-    val = wet_bulb_temperature(pressure, temperature, dewpoint)
+    val = wet_bulb_temperature(pressure, temperature.to(temp_units), dewpoint.to(temp_units))
     truth = [19.238071735308814, 18.033294139060633, 16.65179610640866, 14.341431051131467,
              10.713278865013098, 7.2703265785039, 4.63234087372236, 1.8324379627895773,
              -1.0154897545814394, -4.337334561885717, -8.23596994210175, -11.902727397896111,
@@ -1696,11 +1700,11 @@ def test_el_lfc_most_cape_bottom():
                              13.7, 11.4, 9.1, 6.8, 3.8, 1.5]) * units.degC
     dewpoints = np.array([16.9, 15.9, 14.2, 11, 9.5, 8.6, 0., -3.6, -4.4,
                           -6.9, -9.5, -12., -14.6, -15.8]) * units.degC
-    lfc_pres, lfc_temp = lfc(levels, temperatures, dewpoints, which='most_cape')
-    el_pres, el_temp = el(levels, temperatures, dewpoints, which='most_cape')
-    assert_almost_equal(lfc_pres, 900.73235 * units.hPa, 3)
+    lfc_pressure, lfc_temp = lfc(levels, temperatures, dewpoints, which='most_cape')
+    el_pressure, el_temp = el(levels, temperatures, dewpoints, which='most_cape')
+    assert_almost_equal(lfc_pressure, 900.73235 * units.hPa, 3)
     assert_almost_equal(lfc_temp, 14.672512 * units.degC, 3)
-    assert_almost_equal(el_pres, 849.7998947 * units.hPa, 3)
+    assert_almost_equal(el_pressure, 849.7998947 * units.hPa, 3)
     assert_almost_equal(el_temp, 12.4233265 * units.degC, 3)
 
 
@@ -1830,7 +1834,7 @@ def test_cape_cin_value_error():
     assert_almost_equal(cin, expected_cin, 3)
 
 
-def test_lcl_grid_surface_LCLs():
+def test_lcl_grid_surface_lcls():
     """Test surface grid where some values have LCLs at the surface."""
     pressure = np.array([1000, 990, 1010]) * units.hPa
     temperature = np.array([15, 14, 13]) * units.degC
@@ -1863,8 +1867,8 @@ def test_lifted_index():
                          -34.1, -37.3, -32.3, -34.1, -37.3, -41.1, -37.7, -58.1,
                          -57.5]) * units.degC
     parcel_prof = parcel_profile(pressure, temperature[0], dewpoint[0])
-    LI = lifted_index(pressure, temperature, parcel_prof)
-    assert_almost_equal(LI, -7.9176350 * units.delta_degree_Celsius, 2)
+    li = lifted_index(pressure, temperature, parcel_prof)
+    assert_almost_equal(li, -7.9176350 * units.delta_degree_Celsius, 2)
 
 
 def test_gradient_richardson_number():
@@ -1902,3 +1906,23 @@ def test_gradient_richardson_number_with_xarray():
     assert isinstance(result, xr.DataArray)
     xr.testing.assert_identical(result['height'], data['Ri_g']['height'])
     assert_array_almost_equal(result.data.m_as(''), data['Ri_g'].data)
+
+
+def test_showalter_index():
+    """Test the Showalter index calculation."""
+    pressure = units.Quantity(np.array([931.0, 925.0, 911.0, 891.0, 886.9, 855.0, 850.0, 825.6,
+                                        796.3, 783.0, 768.0, 759.0, 745.0, 740.4, 733.0, 715.0,
+                                        700.0, 695.0, 687.2, 684.0, 681.0, 677.0, 674.0, 661.9,
+                                        657.0, 639.0, 637.6, 614.0, 592.0, 568.9, 547.4, 526.8,
+                                        500.0, 487.5, 485.0]), 'hPa')
+    temps = units.Quantity(np.array([18.4, 19.8, 20.0, 19.6, 19.3, 16.8, 16.4, 15.1, 13.4,
+                                     12.6, 11.2, 10.4, 8.6, 8.3, 7.8, 5.8, 4.6, 4.2, 3.4, 3.0,
+                                     3.0, 4.4, 5.0, 5.1, 5.2, 3.4, 3.3, 2.4, 1.4, -0.4, -2.2,
+                                     -3.9, -6.3, -7.6, -7.9]), 'degC')
+    dewp = units.Quantity(np.array([9.4, 8.8, 6.0, 8.6, 8.4, 6.8, 6.4, 4.0, 1.0, -0.4, -1.1,
+                                    -1.6, 1.6, -0.2, -3.2, -3.2, -4.4, -2.8, -3.6, -4.0, -6.0,
+                                    -17.6, -25.0, -31.2, -33.8, -29.6, -30.1, -39.0, -47.6,
+                                    -48.9, -50.2, -51.5, -53.3, -55.5, -55.9]), 'degC')
+
+    result = showalter_index(pressure, temps, dewp)
+    assert_almost_equal(result, units.Quantity(7.6024, 'delta_degC'), 4)
