@@ -9,7 +9,6 @@ import logging
 import numpy as np
 from numpy.testing import assert_array_almost_equal
 import pytest
-import scipy
 
 from metpy.cbook import get_test_data
 from metpy.interpolate.grid import (generate_grid, generate_grid_coords, get_boundary_coords,
@@ -165,6 +164,7 @@ def test_inverse_distance_to_grid(method, test_data, test_grid):
     xg, yg = test_grid
 
     extra_kw = {}
+    test_file = ''
     if method == 'cressman':
         extra_kw['r'] = 20
         extra_kw['min_neighbors'] = 1
@@ -182,13 +182,8 @@ def test_inverse_distance_to_grid(method, test_data, test_grid):
     assert_array_almost_equal(truth, img)
 
 
-interp_methods = ['natural_neighbor', 'cressman', 'barnes',
-                  'linear', 'nearest', 'rbf',
-                  pytest.param('cubic',
-                               marks=pytest.mark.skipif(
-                                   scipy.__version__ < '1.2.0',
-                                   reason='Need Scipy >=1.2 for fixed cubic interpolation.'))]
-
+interp_methods = ['natural_neighbor', 'cressman', 'barnes', 'linear', 'nearest', 'rbf',
+                  'cubic']
 boundary_types = [{'west': 80.0, 'south': 140.0, 'east': 980.0, 'north': 980.0},
                   None]
 
@@ -211,23 +206,23 @@ def test_interpolate_to_isosurface():
                     [0.15472957, 0.17382593, 0.20182338, 0.2445138, 0.30252574],
                     [0.15522068, 0.16333457, 0.17633552, 0.19834644, 0.23015555]]])
 
-    thta = np.array([[[344.45776, 344.5063, 344.574, 344.6499, 344.735],
-                      [343.98444, 344.02536, 344.08682, 344.16284, 344.2629],
-                      [343.58792, 343.60876, 343.65628, 343.72818, 343.82834],
-                      [343.21542, 343.2204, 343.25833, 343.32935, 343.43414],
-                      [342.85272, 342.84982, 342.88556, 342.95645, 343.0634]],
-                     [[326.70923, 326.67603, 326.63416, 326.57153, 326.49155],
-                      [326.77695, 326.73468, 326.6931, 326.6408, 326.58405],
-                      [326.95062, 326.88986, 326.83627, 326.78134, 326.7308],
-                      [327.1913, 327.10928, 327.03894, 326.97546, 326.92587],
-                      [327.47235, 327.3778, 327.29468, 327.2188, 327.15973]],
-                     [[318.47897, 318.30374, 318.1081, 317.8837, 317.63837],
-                      [319.155, 318.983, 318.79745, 318.58905, 318.36212],
-                      [319.8042, 319.64206, 319.4669, 319.2713, 319.0611],
-                      [320.4621, 320.3055, 320.13373, 319.9425, 319.7401],
-                      [321.1375, 320.98648, 320.81473, 320.62186, 320.4186]]])
+    theta = np.array([[[344.45776, 344.5063, 344.574, 344.6499, 344.735],
+                       [343.98444, 344.02536, 344.08682, 344.16284, 344.2629],
+                       [343.58792, 343.60876, 343.65628, 343.72818, 343.82834],
+                       [343.21542, 343.2204, 343.25833, 343.32935, 343.43414],
+                       [342.85272, 342.84982, 342.88556, 342.95645, 343.0634]],
+                      [[326.70923, 326.67603, 326.63416, 326.57153, 326.49155],
+                       [326.77695, 326.73468, 326.6931, 326.6408, 326.58405],
+                       [326.95062, 326.88986, 326.83627, 326.78134, 326.7308],
+                       [327.1913, 327.10928, 327.03894, 326.97546, 326.92587],
+                       [327.47235, 327.3778, 327.29468, 327.2188, 327.15973]],
+                      [[318.47897, 318.30374, 318.1081, 317.8837, 317.63837],
+                       [319.155, 318.983, 318.79745, 318.58905, 318.36212],
+                       [319.8042, 319.64206, 319.4669, 319.2713, 319.0611],
+                       [320.4621, 320.3055, 320.13373, 319.9425, 319.7401],
+                       [321.1375, 320.98648, 320.81473, 320.62186, 320.4186]]])
 
-    dt_thta = interpolate_to_isosurface(pv, thta, 2)
+    dt_theta = interpolate_to_isosurface(pv, theta, 2)
 
     truth = np.array([[324.761318, 323.4567137, 322.3276748, 321.3501466, 320.5223535],
                       [330.286922, 327.7779134, 325.797487, 324.3984446, 323.1793418],
@@ -235,7 +230,7 @@ def test_interpolate_to_isosurface():
                       [336.7088576, 336.4165698, 335.6255217, 334.0758288, 331.9684081],
                       [335.6583567, 336.3500714, 336.6844744, 336.3286052, 335.3874244]])
 
-    assert_array_almost_equal(truth, dt_thta)
+    assert_array_almost_equal(truth, dt_theta)
 
 
 @pytest.mark.parametrize('method', interp_methods)
@@ -288,23 +283,23 @@ def test_interpolate_to_isosurface_from_below():
                     [1.7, 1.825, 1.95, 2.075, 2.2],
                     [1.85, 1.975, 2.1, 2.225, 2.35]]])
 
-    thta = np.array([[[330., 350., 370., 390., 410.],
-                      [340., 360., 380., 400., 420.],
-                      [350., 370., 390., 410., 430.],
-                      [360., 380., 400., 420., 440.],
-                      [370., 390., 410., 430., 450.]],
-                     [[320., 340., 360., 380., 400.],
-                      [330., 350., 370., 390., 410.],
-                      [340., 360., 380., 400., 420.],
-                      [350., 370., 390., 410., 430.],
-                      [360., 380., 400., 420., 440.]],
-                     [[310., 330., 350., 370., 390.],
-                      [320., 340., 360., 380., 400.],
-                      [330., 350., 370., 390., 410.],
-                      [340., 360., 380., 400., 420.],
-                      [350., 370., 390., 410., 430.]]])
+    theta = np.array([[[330., 350., 370., 390., 410.],
+                       [340., 360., 380., 400., 420.],
+                       [350., 370., 390., 410., 430.],
+                       [360., 380., 400., 420., 440.],
+                       [370., 390., 410., 430., 450.]],
+                      [[320., 340., 360., 380., 400.],
+                       [330., 350., 370., 390., 410.],
+                       [340., 360., 380., 400., 420.],
+                       [350., 370., 390., 410., 430.],
+                       [360., 380., 400., 420., 440.]],
+                      [[310., 330., 350., 370., 390.],
+                       [320., 340., 360., 380., 400.],
+                       [330., 350., 370., 390., 410.],
+                       [340., 360., 380., 400., 420.],
+                       [350., 370., 390., 410., 430.]]])
 
-    dt_thta = interpolate_to_isosurface(pv, thta, 2, bottom_up_search=False)
+    dt_theta = interpolate_to_isosurface(pv, theta, 2, bottom_up_search=False)
 
     truth = np.array([[330., 350., 370., 385., 400.],
                       [340., 359., 374., 389., 404.],
@@ -312,4 +307,4 @@ def test_interpolate_to_isosurface_from_below():
                       [352., 367., 382., 400., 420.],
                       [356., 371., 390., 410., 430.]])
 
-    assert_array_almost_equal(truth, dt_thta)
+    assert_array_almost_equal(truth, dt_theta)
