@@ -9,15 +9,13 @@ import logging
 import numpy as np
 from numpy.testing import assert_almost_equal, assert_array_almost_equal
 import pytest
-import scipy
 from scipy.spatial import cKDTree, Delaunay
 
 from metpy.cbook import get_test_data
 from metpy.interpolate import (interpolate_to_points, inverse_distance_to_points,
                                natural_neighbor_to_points)
 from metpy.interpolate.geometry import dist_2, find_natural_neighbors
-from metpy.interpolate.points import (barnes_point, cressman_point,
-                                      natural_neighbor_point)
+from metpy.interpolate.points import barnes_point, cressman_point, natural_neighbor_point
 
 logging.getLogger('metpy.interpolate.points').setLevel(logging.ERROR)
 
@@ -120,39 +118,32 @@ def test_inverse_distance_to_points(method, test_data, test_points):
     obs_points = np.vstack([xp, yp]).transpose()
 
     extra_kw = {}
-    if method == 'cressman':
-        extra_kw['r'] = 20
-        extra_kw['min_neighbors'] = 1
-        test_file = 'cressman_r20_mn1.npz'
-    elif method == 'barnes':
-        extra_kw['r'] = 40
-        extra_kw['kappa'] = 100
-        test_file = 'barnes_r40_k100.npz'
-    elif method == 'shouldraise':
+    if method == 'shouldraise':
         extra_kw['r'] = 40
         with pytest.raises(ValueError):
             inverse_distance_to_points(
                 obs_points, z, test_points, kind=method, **extra_kw)
-        return
+    else:
+        test_file = ''
+        if method == 'cressman':
+            extra_kw['r'] = 20
+            extra_kw['min_neighbors'] = 1
+            test_file = 'cressman_r20_mn1.npz'
+        elif method == 'barnes':
+            extra_kw['r'] = 40
+            extra_kw['kappa'] = 100
+            test_file = 'barnes_r40_k100.npz'
 
-    img = inverse_distance_to_points(obs_points, z, test_points, kind=method, **extra_kw)
+        img = inverse_distance_to_points(obs_points, z, test_points, kind=method, **extra_kw)
 
-    with get_test_data(test_file) as fobj:
-        truth = np.load(fobj)['img'].reshape(-1)
+        with get_test_data(test_file) as fobj:
+            truth = np.load(fobj)['img'].reshape(-1)
 
-    assert_array_almost_equal(truth, img)
+        assert_array_almost_equal(truth, img)
 
 
-# SciPy 1.2.0 fixed a bug in cubic interpolation, so we skip on older versions
-interp_methods = ['natural_neighbor', 'cressman', 'barnes',
-                  'linear', 'nearest', 'rbf', 'shouldraise',
-                  pytest.param('cubic',
-                               marks=pytest.mark.skipif(
-                                   scipy.__version__ < '1.2.0',
-                                   reason='Need Scipy >=1.2 for fixed cubic interpolation.'))]
-
-
-@pytest.mark.parametrize('method', interp_methods)
+@pytest.mark.parametrize('method', ['natural_neighbor', 'cressman', 'barnes', 'linear',
+                                    'nearest', 'rbf', 'shouldraise', 'cubic'])
 def test_interpolate_to_points(method, test_data):
     r"""Test main grid interpolation function."""
     xp, yp, z = test_data
