@@ -2,22 +2,16 @@
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
 """Test the cartopy utilities."""
-import contextlib
-
 import matplotlib
 import matplotlib.pyplot as plt
 import pytest
 
-with contextlib.suppress(ImportError):
-    from metpy.plots import USCOUNTIES, USSTATES
-from metpy.plots.cartopy_utils import import_cartopy
-# Fixture to make sure we have the right backend
-from metpy.testing import set_agg_backend  # noqa: F401, I202
+import metpy.plots as mpplots
 
 MPL_VERSION = matplotlib.__version__[:3]
 
 
-@pytest.mark.mpl_image_compare(tolerance={'2.1': 0.161}.get(MPL_VERSION, 0.053),
+@pytest.mark.mpl_image_compare(tolerance={'3.0': 0.161}.get(MPL_VERSION, 0.053),
                                remove_text=True)
 def test_us_county_defaults(ccrs):
     """Test the default US county plotting."""
@@ -26,11 +20,11 @@ def test_us_county_defaults(ccrs):
     fig = plt.figure(figsize=(12, 9))
     ax = fig.add_subplot(1, 1, 1, projection=proj)
     ax.set_extent([270.25, 270.9, 38.15, 38.75], ccrs.Geodetic())
-    ax.add_feature(USCOUNTIES)
+    ax.add_feature(mpplots.USCOUNTIES)
     return fig
 
 
-@pytest.mark.mpl_image_compare(tolerance={'2.1': 0.1994}.get(MPL_VERSION, 0.092),
+@pytest.mark.mpl_image_compare(tolerance={'3.0': 0.1994}.get(MPL_VERSION, 0.092),
                                remove_text=True)
 def test_us_county_scales(ccrs):
     """Test US county plotting with all scales."""
@@ -43,7 +37,7 @@ def test_us_county_scales(ccrs):
 
     for scale, axis in zip(['20m', '5m', '500k'], [ax1, ax2, ax3]):
         axis.set_extent([270.25, 270.9, 38.15, 38.75], ccrs.Geodetic())
-        axis.add_feature(USCOUNTIES.with_scale(scale))
+        axis.add_feature(mpplots.USCOUNTIES.with_scale(scale))
     return fig
 
 
@@ -55,11 +49,11 @@ def test_us_states_defaults(ccrs):
     fig = plt.figure(figsize=(12, 9))
     ax = fig.add_subplot(1, 1, 1, projection=proj)
     ax.set_extent([270, 280, 28, 39], ccrs.Geodetic())
-    ax.add_feature(USSTATES)
+    ax.add_feature(mpplots.USSTATES)
     return fig
 
 
-@pytest.mark.mpl_image_compare(tolerance={'2.1': 0.991}.get(MPL_VERSION, 0.092),
+@pytest.mark.mpl_image_compare(tolerance={'3.0': 0.991}.get(MPL_VERSION, 0.092),
                                remove_text=True)
 def test_us_states_scales(ccrs):
     """Test the default US States plotting with all scales."""
@@ -72,16 +66,30 @@ def test_us_states_scales(ccrs):
 
     for scale, axis in zip(['20m', '5m', '500k'], [ax1, ax2, ax3]):
         axis.set_extent([270, 280, 28, 39], ccrs.Geodetic())
-        axis.add_feature(USSTATES.with_scale(scale))
+        axis.add_feature(mpplots.USSTATES.with_scale(scale))
     return fig
 
 
 def test_cartopy_stub(monkeypatch):
     """Test that the CartoPy stub will issue an error if CartoPy is not present."""
     import sys
+
     # This makes sure that cartopy is not found
     monkeypatch.setitem(sys.modules, 'cartopy.crs', None)
 
-    ccrs = import_cartopy()
-    with pytest.raises(RuntimeError, match='CartoPy is required'):
+    ccrs = mpplots.cartopy_utils.import_cartopy()
+    with pytest.raises(AttributeError, match='without Cartopy'):
         ccrs.PlateCarree()
+
+
+def test_plots_getattr(monkeypatch):
+    """Ensure the module-level getattr works."""
+    # Make sure the feature is missing
+    monkeypatch.delattr(mpplots.cartopy_utils, 'USSTATES', raising=False)
+    with pytest.raises(AttributeError, match='Cannot use USSTATES without Cartopy'):
+        assert not mpplots.USSTATES  # Should fail on attribute lookup before assert
+
+
+def test_plots_dir():
+    """Ensure dir() on metpy.plots works."""
+    assert 'USSTATES' in dir(mpplots)
