@@ -18,12 +18,10 @@ from metpy.cbook import get_test_data
 from metpy.io import GiniFile
 from metpy.io.metar import parse_metar_file
 from metpy.plots import (BarbPlot, ContourPlot, FilledContourPlot, ImagePlot, MapPanel,
-                         PanelContainer, PlotObs)
-# Fixtures to make sure we have the right backend
-from metpy.testing import needs_cartopy, set_agg_backend  # noqa: F401, I202
+                         PanelContainer, PlotGeometry, PlotObs)
+from metpy.testing import needs_cartopy
 from metpy.units import units
 
-
 MPL_VERSION = matplotlib.__version__[:3]
 
 
@@ -51,7 +49,7 @@ def test_declarative_image():
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.256}.get(MPL_VERSION, 0.022))
+                               tolerance={'3.0': 0.256}.get(MPL_VERSION, 0.022))
 @needs_cartopy
 def test_declarative_contour():
     """Test making a contour plot."""
@@ -67,7 +65,7 @@ def test_declarative_contour():
 
     panel = MapPanel()
     panel.area = 'us'
-    panel.proj = 'lcc'
+    panel.projection = 'lcc'
     panel.layers = ['coastline', 'borders', 'usstates']
     panel.plots = [contour]
 
@@ -80,7 +78,7 @@ def test_declarative_contour():
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.256}.get(MPL_VERSION, 0.022))
+                               tolerance={'3.0': 0.216}.get(MPL_VERSION, 0.022))
 @needs_cartopy
 def test_declarative_figsize():
     """Test having an all float figsize."""
@@ -96,7 +94,7 @@ def test_declarative_figsize():
 
     panel = MapPanel()
     panel.area = 'us'
-    panel.proj = 'lcc'
+    panel.projection = 'lcc'
     panel.layers = ['coastline', 'borders', 'usstates']
     panel.plots = [contour]
 
@@ -109,9 +107,9 @@ def test_declarative_figsize():
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.328}.get(MPL_VERSION, 0.022))
+                               tolerance={'3.0': 0.328}.get(MPL_VERSION, 0.022))
 @needs_cartopy
-def test_declarative_contour_CAM():
+def test_declarative_contour_cam():
     """Test making a contour plot with CAM data."""
     data = xr.open_dataset(get_test_data('CAM_test.nc', as_file_obj=False))
 
@@ -151,7 +149,7 @@ def fix_is_closed_polygon(monkeypatch):
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 5.477}.get(MPL_VERSION, 0.035))
+                               tolerance={'3.0': 25.026}.get(MPL_VERSION, 0.0276))
 @needs_cartopy
 def test_declarative_contour_options(fix_is_closed_polygon):
     """Test making a contour plot."""
@@ -169,7 +167,7 @@ def test_declarative_contour_options(fix_is_closed_polygon):
 
     panel = MapPanel()
     panel.area = 'us'
-    panel.proj = 'lcc'
+    panel.projection = 'lcc'
     panel.layers = ['coastline', 'borders', 'usstates']
     panel.plots = [contour]
 
@@ -182,7 +180,7 @@ def test_declarative_contour_options(fix_is_closed_polygon):
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 2.007}.get(MPL_VERSION, 0.035))
+                               tolerance={'3.0': 19.795}.get(MPL_VERSION, 0.0157))
 @needs_cartopy
 def test_declarative_contour_convert_units(fix_is_closed_polygon):
     """Test making a contour plot."""
@@ -201,7 +199,7 @@ def test_declarative_contour_convert_units(fix_is_closed_polygon):
 
     panel = MapPanel()
     panel.area = 'us'
-    panel.proj = 'lcc'
+    panel.projection = 'lcc'
     panel.layers = ['coastline', 'borders', 'usstates']
     panel.plots = [contour]
 
@@ -213,7 +211,8 @@ def test_declarative_contour_convert_units(fix_is_closed_polygon):
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.016)
+@pytest.mark.mpl_image_compare(remove_text=True,
+                               tolerance={'3.0': 0.051}.get(MPL_VERSION, 0.0022))
 @needs_cartopy
 def test_declarative_events():
     """Test that resetting traitlets properly propagates."""
@@ -236,7 +235,7 @@ def test_declarative_events():
 
     panel = MapPanel()
     panel.area = 'us'
-    panel.proj = 'lcc'
+    panel.projection = 'lcc'
     panel.layers = ['coastline', 'borders', 'states']
     panel.plots = [contour, img]
 
@@ -269,6 +268,49 @@ def test_no_field_error():
         contour.draw()
 
 
+def test_ndim_error_scalar(cfeature):
+    """Make sure we get a useful error when the field is not set."""
+    data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
+
+    contour = ContourPlot()
+    contour.data = data
+    contour.field = 'Temperature'
+    contour.level = None
+
+    panel = MapPanel()
+    panel.area = (-110, -60, 25, 55)
+    panel.projection = 'lcc'
+    panel.layers = [cfeature.LAKES]
+    panel.plots = [contour]
+
+    pc = PanelContainer()
+    pc.panel = panel
+
+    with pytest.raises(ValueError):
+        pc.draw()
+
+
+def test_ndim_error_vector(cfeature):
+    """Make sure we get a useful error when the field is not set."""
+    data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
+
+    barbs = BarbPlot()
+    barbs.data = data
+    barbs.field = ['u_wind', 'v_wind']
+    barbs.level = None
+
+    panel = MapPanel()
+    panel.area = (-110, -60, 25, 55)
+    panel.projection = 'lcc'
+    panel.plots = [barbs]
+
+    pc = PanelContainer()
+    pc.panel = panel
+
+    with pytest.raises(ValueError):
+        pc.draw()
+
+
 def test_no_field_error_barbs():
     """Make sure we get a useful error when the field is not set."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
@@ -354,7 +396,7 @@ def test_colorfill_horiz_colorbar(cfeature):
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.355}.get(MPL_VERSION, 0.016))
+                               tolerance={'3.0': 0.355}.get(MPL_VERSION, 0.016))
 def test_colorfill_no_colorbar(cfeature):
     """Test that we can use ContourFillPlot."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
@@ -433,7 +475,7 @@ def test_latlon():
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.418}.get(MPL_VERSION, 0.37))
+                               tolerance={'3.0': 0.418}.get(MPL_VERSION, 0.37))
 @needs_cartopy
 def test_declarative_barb_options():
     """Test making a contour plot."""
@@ -463,11 +505,10 @@ def test_declarative_barb_options():
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.819}.get(MPL_VERSION, 0.612))
+                               tolerance={'3.0': 0.819}.get(MPL_VERSION, 0.612))
 @needs_cartopy
 def test_declarative_barb_earth_relative():
     """Test making a contour plot."""
-    import numpy as np
     data = xr.open_dataset(get_test_data('NAM_test.nc', as_file_obj=False))
 
     contour = ContourPlot()
@@ -503,11 +544,11 @@ def test_declarative_barb_earth_relative():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.612)
+@pytest.mark.mpl_image_compare(remove_text=True,
+                               tolerance={'3.0': 11.481}.get(MPL_VERSION, 0.00936))
 @needs_cartopy
 def test_declarative_gridded_scale():
     """Test making a contour plot."""
-    import numpy as np
     data = xr.open_dataset(get_test_data('NAM_test.nc', as_file_obj=False))
 
     contour = ContourPlot()
@@ -722,8 +763,7 @@ def test_plotobs_subset_time_window_level(sample_obs):
     pd.testing.assert_frame_equal(obs.obsdata, truth)
 
 
-@pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.00142}.get(MPL_VERSION, 0))
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0)
 def test_plotobs_units_with_formatter(ccrs):
     """Test using PlotObs with a field that both has units and a custom formatter."""
     df = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
@@ -760,7 +800,7 @@ def test_plotobs_units_with_formatter(ccrs):
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.407}.get(MPL_VERSION, 0.022))
+                               tolerance={'3.0': 0.407}.get(MPL_VERSION, 0.022))
 def test_declarative_sfc_obs(ccrs):
     """Test making a surface observation plot."""
     data = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
@@ -793,7 +833,7 @@ def test_declarative_sfc_obs(ccrs):
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 8.09}.get(MPL_VERSION, 0.022))
+                               tolerance={'3.0': 8.09}.get(MPL_VERSION, 0.022))
 @needs_cartopy
 def test_declarative_sfc_text():
     """Test making a surface observation plot with text."""
@@ -828,7 +868,7 @@ def test_declarative_sfc_text():
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.407}.get(MPL_VERSION, 0.022))
+                               tolerance={'3.0': 0.407}.get(MPL_VERSION, 0.022))
 def test_declarative_sfc_obs_changes(ccrs):
     """Test making a surface observation plot, changing the field."""
     data = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
@@ -865,7 +905,7 @@ def test_declarative_sfc_obs_changes(ccrs):
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.378}.get(MPL_VERSION, 0.00586))
+                               tolerance={'3.0': 0.352}.get(MPL_VERSION, 0.00586))
 def test_declarative_colored_barbs(ccrs):
     """Test making a surface plot with a colored barb (gh-1274)."""
     data = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
@@ -899,7 +939,7 @@ def test_declarative_colored_barbs(ccrs):
 
 @pytest.mark.mpl_image_compare(remove_text=True,
                                tolerance={'3.1': 9.771,
-                                          '2.1': 9.785}.get(MPL_VERSION, 0.00651))
+                                          '3.0': 9.409}.get(MPL_VERSION, 0.00651))
 def test_declarative_sfc_obs_full(ccrs):
     """Test making a full surface observation plot."""
     data = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
@@ -1080,7 +1120,7 @@ def test_attribute_error_station(ccrs):
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.407}.get(MPL_VERSION, 0.022))
+                               tolerance={'3.0': 0.407}.get(MPL_VERSION, 0.022))
 def test_declarative_sfc_obs_change_units(ccrs):
     """Test making a surface observation plot."""
     data = parse_metar_file(get_test_data('metar_20190701_1200.txt', as_file_obj=False),
@@ -1092,7 +1132,7 @@ def test_declarative_sfc_obs_change_units(ccrs):
     obs.time_window = timedelta(minutes=15)
     obs.level = None
     obs.fields = ['air_temperature']
-    obs.color = ['black']
+    obs.colors = ['black']
     obs.plot_units = ['degF']
 
     # Panel for plot with Map features
@@ -1114,7 +1154,7 @@ def test_declarative_sfc_obs_change_units(ccrs):
 
 
 @pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance={'2.1': 0.09}.get(MPL_VERSION, 0.022))
+                               tolerance={'3.0': 0.09}.get(MPL_VERSION, 0.022))
 def test_declarative_multiple_sfc_obs_change_units(ccrs):
     """Test making a surface observation plot."""
     data = parse_metar_file(get_test_data('metar_20190701_1200.txt', as_file_obj=False),
@@ -1149,6 +1189,203 @@ def test_declarative_multiple_sfc_obs_change_units(ccrs):
     return pc.figure
 
 
+@pytest.mark.mpl_image_compare(remove_text=False, tolerance=0.607)
+@needs_cartopy
+def test_declarative_title_fontsize():
+    """Test adjusting the font size of a MapPanel's title text."""
+    data = xr.open_dataset(get_test_data('NAM_test.nc', as_file_obj=False))
+
+    contour = ContourPlot()
+    contour.data = data
+    contour.field = 'Geopotential_height_isobaric'
+    contour.level = 300 * units.hPa
+    contour.linewidth = 2
+    contour.contours = list(range(0, 2000, 12))
+    contour.scale = 1e-1
+
+    panel = MapPanel()
+    panel.area = (-124, -72, 20, 53)
+    panel.projection = 'lcc'
+    panel.layers = ['coastline', 'borders', 'usstates']
+    panel.plots = [contour]
+    panel.title = '300 mb Geopotential Height'
+    panel.title_fontsize = 20
+
+    pc = PanelContainer()
+    pc.size = (8, 8)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
+@pytest.mark.mpl_image_compare(remove_text=False,
+                               tolerance={'3.1': 11.49,
+                                          '3.0': 11.49}.get(MPL_VERSION, 0.607))
+@needs_cartopy
+def test_declarative_colorbar_fontsize():
+    """Test adjusting the font size of a colorbar."""
+    data = xr.open_dataset(get_test_data('GFS_test.nc', as_file_obj=False))
+
+    cfill = FilledContourPlot()
+    cfill.data = data
+    cfill.field = 'Temperature_isobaric'
+    cfill.level = 300 * units.hPa
+    cfill.time = datetime(2010, 10, 26, 12)
+    cfill.contours = list(range(210, 250, 2))
+    cfill.colormap = 'BuPu'
+    cfill.colorbar = 'horizontal'
+    cfill.colorbar_fontsize = 'x-small'
+
+    panel = MapPanel()
+    panel.area = (-124, -72, 20, 53)
+    panel.projection = 'lcc'
+    panel.layers = ['coastline', 'borders', 'usstates']
+    panel.plots = [cfill]
+
+    pc = PanelContainer()
+    pc.size = (8, 8)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
+@pytest.mark.mpl_image_compare(remove_text=True,
+                               tolerance={'3.1': 2.12,
+                                          '3.0': 4.956}.get(MPL_VERSION, 0.607))
+@needs_cartopy
+def test_declarative_station_plot_fontsize():
+    """Test adjusting the font size for station plots in PlotObs."""
+    data = parse_metar_file(get_test_data('metar_20190701_1200.txt',
+                                          as_file_obj=False), year=2019, month=7)
+    obs = PlotObs()
+    obs.data = data
+    obs.time = datetime(2019, 7, 1, 12)
+    obs.time_window = timedelta(minutes=15)
+    obs.level = None
+    obs.fields = ['cloud_coverage', 'air_temperature', 'dew_point_temperature',
+                  'air_pressure_at_sea_level', 'current_wx1_symbol']
+    obs.plot_units = [None, 'degF', 'degF', None, None]
+    obs.locations = ['C', 'NW', 'SW', 'NE', 'W']
+    obs.formats = ['sky_cover', None, None, lambda v: format(v * 10, '.0f')[-3:],
+                   'current_weather']
+    obs.reduce_points = 3
+    obs.vector_field = ['eastward_wind', 'northward_wind']
+    obs.fontsize = 8
+
+    panel = MapPanel()
+    panel.area = 'centus'
+    panel.projection = 'lcc'
+    panel.layers = ['coastline', 'borders', 'usstates']
+    panel.plots = [obs]
+
+    pc = PanelContainer()
+    pc.size = (8, 8)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
+@pytest.mark.mpl_image_compare(remove_text=True,
+                               tolerance={'3.1': 20.3,
+                                          '3.0': 20.3}.get(MPL_VERSION, 0.607))
+@needs_cartopy
+def test_declarative_contour_label_fontsize():
+    """Test adjusting the font size of contour labels."""
+    data = xr.open_dataset(get_test_data('NAM_test.nc', as_file_obj=False))
+
+    contour = ContourPlot()
+    contour.data = data
+    contour.field = 'Geopotential_height_isobaric'
+    contour.level = 300 * units.hPa
+    contour.linewidth = 2
+    contour.contours = list(range(0, 2000, 12))
+    contour.scale = 1e-1
+    contour.clabels = True
+    contour.label_fontsize = 'xx-large'
+
+    panel = MapPanel()
+    panel.area = (-124, -72, 20, 53)
+    panel.projection = 'lcc'
+    panel.layers = ['coastline', 'borders', 'usstates']
+    panel.plots = [contour]
+
+    pc = PanelContainer()
+    pc.size = (8, 8)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.607)
+@needs_cartopy
+def test_declarative_region_modifier_zoom_in():
+    """Test that '+' suffix on area string properly decreases extent of map."""
+    data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
+
+    contour = ContourPlot()
+    contour.data = data
+    contour.field = 'Temperature'
+    contour.level = 700 * units.hPa
+
+    panel = MapPanel()
+    panel.area = 'sc++'
+    panel.layers = ['coastline', 'borders', 'usstates']
+    panel.plots = [contour]
+
+    pc = PanelContainer()
+    pc.size = (8.0, 8)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.607)
+@needs_cartopy
+def test_declarative_region_modifier_zoom_out():
+    """Test that '-' suffix on area string properly expands extent of map."""
+    data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
+
+    contour = ContourPlot()
+    contour.data = data
+    contour.field = 'Temperature'
+    contour.level = 700 * units.hPa
+
+    panel = MapPanel()
+    panel.area = 'sc-'
+    panel.layers = ['coastline', 'borders', 'usstates']
+    panel.plots = [contour]
+
+    pc = PanelContainer()
+    pc.size = (8.0, 8)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
+@needs_cartopy
+def test_declarative_bad_area():
+    """Test that a invalid string or tuple provided to the area trait raises an error."""
+    panel = MapPanel()
+
+    # Test for string that cannot be grouped into a region and a modifier by regex
+    with pytest.raises(TraitError):
+        panel.area = 'a$z+'
+
+    # Test for string that is not in our list of areas
+    with pytest.raises(TraitError):
+        panel.area = 'PS'
+
+    # Test for nonsense coordinates
+    with pytest.raises(TraitError):
+        panel.area = (136, -452, -65, -88)
+
+
 def test_save():
     """Test that our saving function works."""
     pc = PanelContainer()
@@ -1161,7 +1398,7 @@ def test_save():
     assert fobj.read()
 
 
-def test_show():
+def test_show(set_agg_backend):
     """Test that show works properly."""
     pc = PanelContainer()
 
@@ -1183,3 +1420,181 @@ def test_panel():
 
     pc.panel = panel
     assert pc.panel is panel
+
+
+@needs_cartopy
+def test_copy():
+    """Test that the copy method works for all classes in `declarative.py`."""
+    # Copies of plot objects
+    objects = [ImagePlot(), ContourPlot(), FilledContourPlot(), BarbPlot(), PlotObs(),
+               PlotGeometry()]
+
+    for obj in objects:
+        obj.time = datetime.now()
+        copied_obj = obj.copy()
+        assert obj is not copied_obj
+        assert obj.time == copied_obj.time
+
+    # Copies of MapPanel and PanelContainer
+    obj = MapPanel()
+    obj.title = 'Sample Text'
+    copied_obj = obj.copy()
+    assert obj is not copied_obj
+    assert obj.title == copied_obj.title
+
+    obj = PanelContainer()
+    obj.size = (10, 10)
+    copied_obj = obj.copy()
+    assert obj is not copied_obj
+    assert obj.size == copied_obj.size
+
+    # Copies of plots in MapPanels should not point to same location in memory
+    obj = MapPanel()
+    obj.plots = [PlotObs(), PlotGeometry(), BarbPlot(), FilledContourPlot(), ContourPlot(),
+                 ImagePlot()]
+    copied_obj = obj.copy()
+
+    for i in range(len(obj.plots)):
+        assert obj.plots[i] is not copied_obj.plots[i]
+
+
+@pytest.mark.mpl_image_compare(remove_text=False, tolerance=0.607)
+@needs_cartopy
+def test_declarative_plot_geometry_polygons():
+    """Test that `PlotGeometry` correctly plots MultiPolygon and Polygon objects."""
+    from shapely.geometry import MultiPolygon, Polygon
+
+    # MultiPolygons and Polygons to plot
+    slgt_risk_polygon = MultiPolygon([Polygon(
+        [(-87.43, 41.86), (-91.13, 41.39), (-95.24, 40.99), (-97.47, 40.4), (-98.39, 41.38),
+         (-96.54, 42.44), (-94.02, 44.48), (-92.62, 45.48), (-89.49, 45.91), (-86.38, 44.92),
+         (-86.26, 43.37), (-86.62, 42.45), (-87.43, 41.86), ]), Polygon(
+        [(-74.02, 42.8), (-72.01, 43.08), (-71.42, 42.77), (-71.76, 42.29), (-72.73, 41.89),
+         (-73.89, 41.93), (-74.4, 42.28), (-74.02, 42.8), ])])
+    enh_risk_polygon = Polygon(
+        [(-87.42, 43.67), (-88.44, 42.65), (-90.87, 41.92), (-94.63, 41.84), (-95.13, 42.22),
+         (-95.23, 42.54), (-94.79, 43.3), (-92.81, 43.99), (-90.62, 44.55), (-88.51, 44.61),
+         (-87.42, 43.67)])
+
+    # Plot geometry, set colors and labels
+    geo = PlotGeometry()
+    geo.geometry = [slgt_risk_polygon, enh_risk_polygon]
+    geo.stroke = ['#DDAA00', '#FF6600']
+    geo.fill = None
+    geo.labels = ['SLGT', 'ENH']
+    geo.label_facecolor = ['#FFE066', '#FFA366']
+    geo.label_edgecolor = ['#DDAA00', '#FF6600']
+    geo.label_fontsize = 'large'
+
+    # Place plot in a panel and container
+    panel = MapPanel()
+    panel.area = [-125, -70, 20, 55]
+    panel.projection = 'lcc'
+    panel.title = ' '
+    panel.layers = ['coastline', 'borders', 'usstates']
+    panel.plots = [geo]
+
+    pc = PanelContainer()
+    pc.size = (12, 12)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
+@pytest.mark.mpl_image_compare(remove_text=False, tolerance=2.985)
+def test_declarative_plot_geometry_lines(ccrs):
+    """Test that `PlotGeometry` correctly plots MultiLineString and LineString objects."""
+    from shapely.geometry import LineString, MultiLineString
+
+    # LineString and MultiLineString to plot
+    irma_fcst = LineString(
+        [(-52.3, 16.9), (-53.9, 16.7), (-56.2, 16.6), (-58.6, 17.0), (-61.2, 17.8),
+         (-63.9, 18.7), (-66.8, 19.6), (-72.0, 21.0), (-76.5, 22.0)])
+    irma_fcst_shadow = MultiLineString([LineString(
+        [(-52.3, 17.15), (-53.9, 16.95), (-56.2, 16.85), (-58.6, 17.25), (-61.2, 18.05),
+         (-63.9, 18.95), (-66.8, 19.85), (-72.0, 21.25), (-76.5, 22.25)]), LineString(
+        [(-52.3, 16.65), (-53.9, 16.45), (-56.2, 16.35), (-58.6, 16.75), (-61.2, 17.55),
+         (-63.9, 18.45), (-66.8, 19.35), (-72.0, 20.75), (-76.5, 21.75)])])
+
+    # Plot geometry, set colors and labels
+    geo = PlotGeometry()
+    geo.geometry = [irma_fcst, irma_fcst_shadow]
+    geo.fill = None
+    geo.stroke = 'green'
+    geo.labels = ['Irma', '+/- 0.25 deg latitude']
+    geo.label_facecolor = None
+
+    # Place plot in a panel and container
+    panel = MapPanel()
+    panel.area = [-85, -45, 12, 25]
+    panel.projection = ccrs.PlateCarree()
+    panel.layers = ['coastline', 'borders', 'usstates']
+    panel.title = 'Hurricane Irma Forecast'
+    panel.plots = [geo]
+
+    pc = PanelContainer()
+    pc.size = (12, 12)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
+@pytest.mark.mpl_image_compare(remove_text=False, tolerance=1.900)
+def test_declarative_plot_geometry_points(ccrs):
+    """Test that `PlotGeometry` correctly plots Point and MultiPoint objects."""
+    from shapely.geometry import MultiPoint, Point
+
+    # Points and MultiPoints to plot
+    irma_track = [Point(-74.7, 21.8), Point(-76.0, 22.0), Point(-77.2, 22.1)]
+    irma_track_shadow = MultiPoint([
+        Point(-64.7, 18.25), Point(-66.0, 18.85), Point(-67.7, 19.45), Point(-69.0, 19.85),
+        Point(-70.4, 20.45), Point(-71.8, 20.85), Point(-73.2, 21.25), Point(-74.7, 21.55),
+        Point(-76.0, 21.75), Point(-77.2, 21.85), Point(-78.3, 22.05), Point(-79.3, 22.45),
+        Point(-80.2, 22.85), Point(-80.9, 23.15), Point(-81.3, 23.45), Point(-81.5, 24.25),
+        Point(-81.7, 25.35), Point(-81.7, 26.55), Point(-82.2, 27.95), Point(-82.7, 29.35),
+        Point(-83.5, 30.65), Point(-84.4, 31.65)])
+
+    # Plot geometry, set colors and labels
+    geo = PlotGeometry()
+    geo.geometry = irma_track + [irma_track_shadow]
+    geo.fill = 'blue'
+    geo.stroke = None
+    geo.marker = '^'
+    geo.labels = ['Point', 'Point', 'Point', 'Irma Track']
+    geo.label_edgecolor = None
+    geo.label_facecolor = None
+
+    # Place plot in a panel and container
+    panel = MapPanel()
+    panel.area = [-85, -65, 17, 30]
+    panel.projection = ccrs.PlateCarree()
+    panel.layers = ['states', 'coastline', 'borders']
+    panel.plots = [geo]
+
+    pc = PanelContainer()
+    pc.size = (12, 12)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
+@needs_cartopy
+def test_drop_traitlets_dir():
+    """Test successful drop of inherited members from HasTraits and any '_' or '__' members."""
+    for plot_obj in (
+            BarbPlot,
+            ContourPlot,
+            FilledContourPlot,
+            ImagePlot,
+            MapPanel,
+            PanelContainer,
+            PlotGeometry,
+            PlotObs
+    ):
+        assert dir(plot_obj)[0].startswith('_')
+        assert not dir(plot_obj())[0].startswith('_')
+        assert 'cross_validation_lock' in dir(plot_obj)
+        assert 'cross_validation_lock' not in dir(plot_obj())
