@@ -10,16 +10,12 @@ import numpy as np
 import pytest
 
 from metpy.plots import Hodograph, SkewT
-# Fixtures to make sure we have the right backend and consistent round
-from metpy.testing import set_agg_backend  # noqa: F401, I202
 from metpy.units import units
 
-
 MPL_VERSION = matplotlib.__version__[:3]
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, style='default',
-                               tolerance={'2.1': 1.118}.get(MPL_VERSION, 0.02))
+@pytest.mark.mpl_image_compare(remove_text=True, style='default', tolerance=0.023)
 def test_skewt_api():
     """Test the SkewT API."""
     with matplotlib.rc_context({'axes.autolimit_mode': 'data'}):
@@ -51,7 +47,7 @@ def test_skewt_api():
 
 
 @pytest.mark.mpl_image_compare(remove_text=True, style='default',
-                               tolerance={'2.1': 34.37}.get(MPL_VERSION, 0.02))
+                               tolerance={'3.0': 34.37}.get(MPL_VERSION, 0.02))
 def test_skewt_api_units():
     """#Test the SkewT API when units are provided."""
     with matplotlib.rc_context({'axes.autolimit_mode': 'data'}):
@@ -318,6 +314,24 @@ def test_hodograph_units():
     return fig
 
 
+@pytest.mark.mpl_image_compare(tolerance=0, remove_text=True)
+def test_hodograph_masked_array():
+    """Basic test of Hodograph API."""
+    fig = plt.figure(figsize=(9, 9))
+    ax = fig.add_subplot(1, 1, 1)
+    hodo = Hodograph(ax, component_range=20)
+    u = np.ma.array([1, 3, 5, 10])
+    v = np.ma.array([2, 4, 6, 11])
+    h = units.Quantity(np.array([0.1, 3.5, 5.5, 10.9]), 'km')
+    intervals = units.Quantity(np.array([0.0, 3.0, 6.0, 9.0, 12.0, 15.0]), 'km')
+    colors = ['red', 'green', 'yellow', 'blue', 'purple']
+    # Check that we're not triggering interpolation warnings
+    with pytest.warns(None) as record:
+        hodo.plot_colormapped(u, v, h, intervals=intervals, colors=colors)
+        assert len(record) == 0
+    return fig
+
+
 def test_hodograph_alone():
     """Test to create Hodograph without specifying axes."""
     Hodograph()
@@ -485,8 +499,6 @@ def test_hodograph_wind_vectors():
     return fig
 
 
-@pytest.mark.skipif(matplotlib.__version__ < '3.0.1',
-                    reason="Earlier Matplotlib versions don't have a required fix.")
 def test_united_hodograph_range():
     """Tests making a hodograph with a united ranged."""
     fig = plt.figure(figsize=(6, 6))
