@@ -9,13 +9,10 @@ import numpy as np
 import pandas as pd
 import pytest
 
-from metpy.plots import (current_weather, high_clouds, nws_layout, simple_layout,
-                         sky_cover, StationPlot, StationPlotLayout)
-# Fixtures to make sure we have the right backend and consistent round
-from metpy.testing import set_agg_backend  # noqa: F401, I202
+from metpy.plots import (current_weather, high_clouds, nws_layout, simple_layout, sky_cover,
+                         StationPlot, StationPlotLayout)
 from metpy.units import units
 
-
 MPL_VERSION = matplotlib.__version__[:3]
 
 
@@ -187,7 +184,7 @@ def test_simple_layout():
             'air_pressure_at_sea_level': np.array([29.92, 28.00]) * units.inHg,
             'eastward_wind': np.array([2, 0]) * units.knots,
             'northward_wind': np.array([0, 5]) * units.knots, 'cloud_coverage': [3, 8],
-            'present_weather': [65, 75], 'unused': [1, 2]}
+            'current_wx1_symbol': [65, 75], 'unused': [1, 2]}
 
     # Make the plot
     sp = StationPlot(fig.add_subplot(1, 1, 1), x, y, fontsize=12)
@@ -212,7 +209,7 @@ def test_nws_layout():
             'air_pressure_at_sea_level': np.array([999.8]) * units('mbar'),
             'eastward_wind': np.array([15.]) * units.knots,
             'northward_wind': np.array([15.]) * units.knots, 'cloud_coverage': [7],
-            'present_weather': [80], 'high_cloud_type': [1], 'medium_cloud_type': [3],
+            'current_wx1_symbol': [80], 'high_cloud_type': [1], 'medium_cloud_type': [3],
             'low_cloud_type': [2], 'visibility_in_air': np.array([5.]) * units.mile,
             'tendency_of_air_pressure': np.array([-0.3]) * units('mbar'),
             'tendency_of_air_pressure_symbol': [8]}
@@ -281,7 +278,7 @@ def wind_plot():
     return u, v, x, y
 
 
-@pytest.mark.mpl_image_compare(tolerance={'2.1': 0.0423}.get(MPL_VERSION, 0.00434),
+@pytest.mark.mpl_image_compare(tolerance={'3.0': 0.04231}.get(MPL_VERSION, 0.00434),
                                remove_text=True)
 def test_barb_projection(wind_plot, ccrs):
     """Test that barbs are properly projected (#598)."""
@@ -297,7 +294,7 @@ def test_barb_projection(wind_plot, ccrs):
     return fig
 
 
-@pytest.mark.mpl_image_compare(tolerance={'2.1': 0.0693}.get(MPL_VERSION, 0.00382),
+@pytest.mark.mpl_image_compare(tolerance={'3.0': 0.0693}.get(MPL_VERSION, 0.00382),
                                remove_text=True)
 def test_arrow_projection(wind_plot, ccrs):
     """Test that arrows are properly projected."""
@@ -459,7 +456,6 @@ def test_stationplot_unit_conversion():
 
 def test_scalar_unit_conversion_exception():
     """Test that errors are raise if unit conversion is requested on un-united data."""
-    T = 50
     x_pos = np.array([0])
     y_pos = np.array([0])
 
@@ -467,4 +463,4 @@ def test_scalar_unit_conversion_exception():
     ax = fig.add_subplot(1, 1, 1)
     stnplot = StationPlot(ax, x_pos, y_pos)
     with pytest.raises(ValueError):
-        stnplot.plot_parameter('C', T, plot_units='degC')
+        stnplot.plot_parameter('C', 50, plot_units='degC')
