@@ -14,14 +14,9 @@ from metpy.plots.mapping import CFProjection
 from metpy.testing import (assert_almost_equal, assert_array_almost_equal, assert_array_equal,
                            get_test_data)
 from metpy.units import DimensionalityError, units
-from metpy.xarray import (
-    add_grid_arguments_from_xarray,
-    add_vertical_dim_from_xarray,
-    check_axis,
-    check_matching_coordinates,
-    grid_deltas_from_dataarray,
-    preprocess_and_wrap
-)
+from metpy.xarray import (add_grid_arguments_from_xarray, add_vertical_dim_from_xarray,
+                          check_axis, check_matching_coordinates, grid_deltas_from_dataarray,
+                          preprocess_and_wrap)
 
 
 @pytest.fixture
@@ -1069,8 +1064,8 @@ def test_update_attribute_dictionary(test_ds_generic):
 def test_update_attribute_callable(test_ds_generic):
     """Test update_attribute using callable."""
     def even_ascii(varname, **kwargs):
-        if ord(varname[0]) % 2 == 0:
-            return 'yes'
+        return 'yes' if ord(varname[0]) % 2 == 0 else None
+
     result = test_ds_generic.metpy.update_attribute('even', even_ascii)
 
     # Test attribute updates
